==> ctf-all-in-one-2018-1-24-2024.3.3.0.tar.gz: ctf-all-in-one-2018-1-24-2024.3.3.0/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

import setuptools
import CtfAllInOne2018124
import os
from os import path

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

for subdir, _, _ in os.walk('CtfAllInOne2018124'):
    fname = path.join(subdir, '__init__.py')
    open(fname, 'a').close()
    
setuptools.setup(
    name="ctf-all-in-one-2018-1-24",
    version=CtfAllInOne2018124.__version__,
    url="https://github.com/apachecn/ctf-all-in-one-2018-1-24",
    author=CtfAllInOne2018124.__author__,
    author_email=CtfAllInOne2018124.__email__,
    classifiers=[
        "Development Status :: 4 - Beta",
        "Environment :: Console",
        "Intended Audience :: Developers",
        "Intended Audience :: End Users/Desktop",
        "License :: Other/Proprietary License",
        "Natural Language :: Chinese (Simplified)",
        "Natural Language :: English",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Topic :: Text Processing :: Markup :: Markdown",
        "Topic :: Text Processing :: Markup :: HTML",
        "Topic :: Internet :: WWW/HTTP",
        "Topic :: Software Development :: Documentation",
        "Topic :: Documentation",
    ],
    description="CTF-All-In-One 2018.1.24",
    long_description=long_description,
    long_description_content_type="text/markdown",
    keywords=[],
    install_requires=[],
    python_requires=">=3.6",
    entry_points={
        'console_scripts': [
            "ctf-all-in-one-2018-1-24=CtfAllInOne2018124.__main__:main",
            "CtfAllInOne2018124=CtfAllInOne2018124.__main__:main",
        ],
    },
    packages=setuptools.find_packages(),
    package_data={'': ['*']},
)

==> ctf-all-in-one-20171015-2024.3.2.0.tar.gz: ctf-all-in-one-20171015-2024.3.2.0/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

import setuptools
import CtfAllInOne20171015
import os
from os import path

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

for subdir, _, _ in os.walk('CtfAllInOne20171015'):
    fname = path.join(subdir, '__init__.py')
    open(fname, 'a').close()
    
setuptools.setup(
    name="ctf-all-in-one-20171015",
    version=CtfAllInOne20171015.__version__,
    url="https://github.com/apachecn/ctf-all-in-one-20171015",
    author=CtfAllInOne20171015.__author__,
    author_email=CtfAllInOne20171015.__email__,
    classifiers=[
        "Development Status :: 4 - Beta",
        "Environment :: Console",
        "Intended Audience :: Developers",
        "Intended Audience :: End Users/Desktop",
        "License :: Other/Proprietary License",
        "Natural Language :: Chinese (Simplified)",
        "Natural Language :: English",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Topic :: Text Processing :: Markup :: Markdown",
        "Topic :: Text Processing :: Markup :: HTML",
        "Topic :: Internet :: WWW/HTTP",
        "Topic :: Software Development :: Documentation",
        "Topic :: Documentation",
    ],
    description="CTF-All-In-One 20171015",
    long_description=long_description,
    long_description_content_type="text/markdown",
    keywords=[],
    install_requires=[],
    python_requires=">=3.6",
    entry_points={
        'console_scripts': [
            "ctf-all-in-one-20171015=CtfAllInOne20171015.__main__:main",
            "CtfAllInOne20171015=CtfAllInOne20171015.__main__:main",
        ],
    },
    packages=setuptools.find_packages(),
    package_data={'': ['*']},
)
